#!/usr/bin/env bash
# -*- coding: utf-8 -*-
# coding: utf-8
# vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2
# vim: set fileencoding=utf-8
source /scripts/basic_vars
set -o nounset
set -o pipefail
set -o errexit
#
if [ "3" != "$#" ]; then exit 0; fi
#
exec 1> >(systemd-cat -p info -t app_execute) 2>&1
set -o xtrace
#
if [ -z "${is_native_applications_enabled_in_config}" ]; then
  echo "Native applications are disabled in configuration!"
  exit 3
fi
if [ ! -f ${VERIFIED_LICENSE_FILE} ]; then
  echo "No valid license !"
  exit 4
fi
if [ -z "${is_native_app_enabled_in_license}" ]; then
  echo "Native applications not allowed by a valid license !";
  exit 5
fi
#
APPNAME=${1}
OPERATION=${2}
AUUID=${3}
OUTFILE=/tmp/application_execute_${AUUID}.out
#
if [ -n "$(echo ${APPNAME} | grep --ignore-case clavister)" ] \
   && [ -z "${is_native_app_clavister_enabled_in_license}" ]; then
  echo "Native application Clavister not allowed by a valid license !"
  exit 5
elif [ -n "$(echo ${APPNAME} | grep --ignore-case mikrotik)" ] \
     && [ -z "${is_native_app_mikrotik_enabled_in_license}" ]; then
  echo "Native application MikroTik not allowed by a valid license !"
  exit 5
fi
#
APPDIR=/root/apps/${APPNAME}
RUNNINGFILE=/run/running${APPNAME}app.txt
APPJSON=/root/apps/${APPNAME}/config/application.json
if [ ! -f ${APPJSON} ]; then
  echo "Missing application.json"
  exit 6
fi
CONFIG=$(jq '.config' ${APPDIR}/config/application.json | tr -d '"')
if [ ! -f ${APPDIR}/config/${CONFIG} ]; then
  echo "Missing config.json"
  exit 7
fi
if [ ! -f ${RUNNINGFILE} ]; then
  echo "Still booting"
  exit 13
fi
ALLOWED_OPERATION="$(jq '.config_entities [] .name' ${APPDIR}/config/${CONFIG} | tr -d '"' | tr -s '\r\n' ' ')"
if [ -z "$(echo ${ALLOWED_OPERATION} | grep --word-regexp ${OPERATION})" ]; then
  echo "Operation not allowed in config.json"
  exit 8
fi
REST_CALL_SUPPORTED=$(jq --arg OPERATION "$OPERATION" '.config_entities [] | select(.name == $OPERATION) .rest_call_supported' ${APPDIR}/config/${CONFIG})
if [ -z "$(echo ${REST_CALL_SUPPORTED} | grep --word-regexp --ignore-case true)" ]; then
  echo "Operation is not rest-call-supported"
  exit 9
fi
if [ ! -x ${APPDIR}/${OPERATION}.sh ]; then
  echo "Missing operation executable script"
  exit 1
fi
${APPDIR}/${OPERATION}.sh > ${OUTFILE}
exit 0
