#!/usr/bin/env bash
# -*- coding: utf-8 -*-
# coding: utf-8
# vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2
# vim: set fileencoding=utf-8
source /scripts/basic_vars
set -o nounset
set -o pipefail
set -o errexit
#
if [ "1" != "$#" ]; then exit 0; fi
exec 1> >(systemd-cat -p info -t app_retrieve) 2>&1
set -o xtrace
#
if [ -z "${is_native_applications_enabled_in_config}" ]; then
  echo "Native applications are disabled in configuration!"
  exit 3
fi
if [ ! -f ${VERIFIED_LICENSE_FILE} ]; then
  echo "No valid license !"
  exit 4
fi
if [ -z "${is_native_app_enabled_in_license}" ]; then
  echo "Native applications not allowed by a valid license !";
  exit 5
fi
#
APPNAME=${1}
#
if [ -n "$(echo ${APPNAME} | grep --ignore-case clavister)" ] \
   && [ -z "${is_native_app_clavister_enabled_in_license}" ]; then
  echo "Native application Clavister not allowed by a valid license !"
  exit 5
elif [ -n "$(echo ${APPNAME} | grep --ignore-case mikrotik)" ] \
     && [ -z "${is_native_app_mikrotik_enabled_in_license}" ]; then
  echo "Native application MikroTik not allowed by a valid license !"
  exit 5
fi
#
EXCLUDE_FILE=""
#
cd /root/apps/${APPNAME}
shopt -s nocasematch
if [[ "${APPNAME}" == "clavister"* ]] || [[ "${APPNAME}" == "mikrotik"* ]]; then
  EXCLUDE_FILE="--exclude=clav_ifs_setup --exclude=mikrotik_ifs_setup --exclude=successful_initialized"
elif [[ "${APPNAME}" == "slmprobe"* ]]; then
  EXCLUDE_FILE="--exclude=opentsdb.json --exclude=opentsdb.txt --exclude=ping.txt --exclude=tsdb.json --exclude=config.json.temp --exclude=.lat --exclude=.lon"
fi
shopt -u nocasematch
tar ${EXCLUDE_FILE} -czf /home/admin/user_files/${APPNAME}.tar.gz *
cd /tmp
exit 0
