#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import re
import subprocess
import signal
import sys
import xml.etree.ElementTree as ET


def signal_handler(_, __):
    print('\nTerminated by the user!')
    sys.exit(1)  # Exit the program with a status code of 1


def get_all_intf_names():
    try:
        output = subprocess.check_output(['sysrepocfg', '--datastore=running', '--format=xml',
                                          "--xpath=/ucpe:config/interfaces:interface/name",
                                          '--export']).decode().strip()
        root = ET.fromstring(output)
        namespaces = {'ucpe': 'urn:ucpe', 'interfaces': 'urn:interfaces'}
        intf_names = [elem.text.strip() for elem in root.findall(".//{urn:interfaces}name", namespaces)]
        return intf_names

    except Exception as e:
        print(f"Failed to obtain interface names. Error: {e}.")
        return []


if __name__ == "__main__":
    signal.signal(signal.SIGINT, signal_handler)
    argc = len(sys.argv)
    all_interfaces = get_all_intf_names()

    interface = sys.argv[1]

    if '.' in interface:
        interface = interface.split('.')[0]
        if interface in all_interfaces:
            sys.exit(0)
        else:
            print(f'This interface cannot be configured because the {interface} interface does not exist.')
            sys.exit(1)

    if interface in all_interfaces:
        sys.exit(0)
    else:
        print('There is no such interface!')
        sys.exit(1)

